#! /bin/bash

SOCKET_PATH="/tmp/pikainstall-status.sock"

# Clear fstab
echo 'GEN_FSTAB' | nc -U $SOCKET_PATH || true
touch /etc/fstab
# Generate fstab entries
dpkg -s arch-install-scripts || apt install -y arch-install-scripts cryptsetup
genfstab -U / | grep -v zram | grep -v portal | grep -v loop | grep -v cdrom | grep -v swap > /etc/fstab
# Enable zram if there's no swaplist
if [ ! -f /tmp/pika-installer-gtk4-swaplist ]
then
	apt install -y /var/cache/apt/archives/zram-tools*.deb
	echo -e "ALGO=zstd\nPERCENT=25" | tee -a /etc/default/zramswap
	systemctl enable zramswap || true
fi
# Remove packages that are only needed for the live session
apt autoremove -y
# Setup Crypttab if needed
if [ -f /var/albius-crypttab-root.sh ]
then
	echo 'ENCRYPTION' | nc -U $SOCKET_PATH || true
	chmod +x /var/albius-crypttab-root.sh
	/var/albius-crypttab-root.sh
fi
if [ -f /var/albius-crypttab.sh ]
then
	echo 'ENCRYPTION' | nc -U $SOCKET_PATH || true
	chmod +x /var/albius-crypttab.sh
	/var/albius-crypttab.sh
fi
echo 'LOCALE' | nc -U $SOCKET_PATH || true
# Generate locales
locale-gen || true
# Setup keyboard and locales
chmod +x /var/albius-lang_linux.sh
/var/albius-lang_linux.sh
# Setup the refind bootloader
echo 'BOOTLOADER' | nc -U $SOCKET_PATH || true
chmod +x /var/albius-refind_linux.sh
/var/albius-refind_linux.sh
refind-install
apt install -y /var/cache/apt/archives/pika-refind-theme*.deb /var/cache/apt/archives/booster*.deb
# EFI workaround for MSI
mkdir -p /boot/efi/EFI/BOOT
cp -vf  /boot/efi/EFI/refind/refind_x64.efi /boot/efi/EFI/BOOT/BOOTX64.EFI
refind-install
# Remove installer from installed system
echo 'LIVE_REMOVE' | nc -U $SOCKET_PATH || true
apt remove live-boot pika-installer-gtk4 -y || true
apt autoremove -y || true
# Create first setup user
echo 'BASIC_USER' | nc -U $SOCKET_PATH || true
useradd -m -k -U pikaos || true
echo pikaos:pikaos | chpasswd || true
usermod -a -G sudo pikaos || true
mkdir -p /home/pikaos || true
cp -rvf /etc/skel/.* /home/pikaos/ || true
mkdir -p /home/pikaos/.config/autostart || true
cp /usr/share/applications/pika-first-setup.desktop /home/pikaos/.config/autostart || true
cp /usr/share/applications/com.github.pikaos-linux.pikafirstsetup.desktop /home/pikaos/.config/autostart || true
chown -R pikaos:pikaos /home/pikaos || true
